From 243bdaff75853606ce477807e87e4fbcc1decfb1 Mon Sep 17 00:00:00 2001 From: Siva Mahadevan Date: Sat, 12 Sep 2026 14:29:02 -0400 Subject: [PATCH] lib/googletest: also use -O0 for internal tests with GCC This fixes the build with gcc 16's aggressive inlining. Reviewed by: ngie MFC after: 3 days Sponsored by: The FreeBSD Foundation Differential Revision: https://reviews.freebsd.org/D59538 --- lib/googletest/tests/Makefile.inc | 6 +++--- 1 file changed, 3 insertions(+), 3 deletions(-) diff --git a/lib/googletest/tests/Makefile.inc b/lib/googletest/tests/Makefile.inc index 8d19e1fafdea..d697507c9e5e 100644 --- a/lib/googletest/tests/Makefile.inc +++ b/lib/googletest/tests/Makefile.inc @@ -5,14 +5,14 @@ TESTSDIR= ${TESTSBASE}/lib/googletest/${.CURDIR:T} PACKAGE= tests -# Clang's optimizer spends a really long time on these tests at -O2. Changing +# Both GCC's and Clang's optimizer spends a really long time on these tests at -O2. Changing # -O2 to -O1 reduces the -j32 time for lib/googletest/test from 131s to 71s. # Using -O0 further reduces the time to 29s, and also reduces the disk usage # from 144MB (at -O2) / 92MB (at -O1) to 82MB, so we use -O0. # Note: Building without debug info saves about 10-15% of the build time, so we # only enable debug info if DEBUG_FLAGS is not empty (71s -> 64s at -O1 and -j32). -CFLAGS.clang+= -O0 +CFLAGS+= -O0 .if empty(DEBUG_FLAGS) MK_DEBUG_FILES:=no -CFLAGS.clang+= -g0 +CFLAGS+= -g0 .endif